@@ -46,10 +46,10 @@ $LANG01 = array(
     2 => 'read more',
     3 => 'comments',
     4 => 'Edit',
-    5 => 'Vote',
-    6 => 'Results',
+    5 => '',
+    6 => '',
     7 => '',
-    8 => 'votes',
+    8 => '',
     9 => 'Admin Functions:',
     10 => 'Submissions',
     11 => 'Stories',
@@ -81,7 +81,7 @@ $LANG01 = array(
     37 => 'No user stories',
     38 => 'Content Syndication',
     39 => 'Refresh',
-    40 => 'You have <tt>register_globals = Off</tt> in your <tt>php.ini</tt>. However, Geeklog requires <tt>register_globals</tt> to be <strong>on</strong>. Before you continue, please set it to <strong>on</strong> and restart your web server.',
+    40 => '',
     41 => 'Guest Users',
     42 => 'Authored by:',
     43 => 'Reply to This',
@@ -136,7 +136,7 @@ $LANG01 = array(
     92 => 'seconds',
     93 => 'Copyright',
     94 => 'All trademarks and copyrights on this page are owned by their respective owners.',
-    95 => 'Powered By',
+    95 => 'Powered by',
     96 => 'Groups',
     97 => 'Word List',
     98 => 'Plugins',
@@ -152,7 +152,7 @@ $LANG01 = array(
     108 => 'Clear Cache',
     109 => 'Report abuse',
     110 => 'Report this post to the site admin',
-    111 => 'View PDF Version',
+    111 => '',
     112 => 'Registered Users',
     113 => 'Documentation',
     114 => 'Trackbacks',
@@ -204,7 +204,24 @@ $LANG03 = array(
     24 => 'Anonymous User',
     25 => 'Are you sure you want to report this post to the site admin?',
     26 => '%s reported the following abusive comment post:',
-    27 => 'Abuse report'
+    27 => 'Abuse report',
+    28 => 'Preview Changes',
+    29 => 'Submit Changes',
+    30 => 'Edited on',
+    31 => 'by',
+    32 => 'Editing a Comment',
+    33 => 'Editing a Comment Submission',
+    34 => 'Preview Submission Changes',
+    35 => 'Save Changes to Queue',
+    36 => 'Notify me of new replies',
+    37 => 'New Comment Reply',
+    38 => "A reply has been made to your comment '%s'.",
+    39 => 'You may view the comment thread at the following address:',
+    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
+    41 => 'Hello %s,',
+    42 => 'Unsubscribe',
+    43 => 'Unsubscribe from reply notifications',
+    44 => 'Your Name'
 );
 
 ###############################################################################
@@ -212,7 +229,7 @@ $LANG03 = array(
 
 $LANG04 = array(
     1 => 'User Profile for',
-    2 => 'User Name',
+    2 => 'Username',
     3 => 'Full Name',
     4 => 'New Password',
     5 => 'Email',
@@ -350,7 +367,7 @@ $LANG04 = array(
     137 => 'Filter Story Content',
     138 => 'Misc Settings',
     139 => 'Layout and Language',
-    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and perferred date format</li>',
+    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
     141 => 'Privacy Settings',
     142 => 'The default setting is to allow users &amp; admins to email fellow site members and show your status as online. Un-check these options to protect your privacy.',
     143 => 'Filter Block Content',
@@ -364,7 +381,13 @@ $LANG04 = array(
     156 => 'Delete Account',
     157 => 'Delete Option',
     158 => 'Time Zone',
-    159 => 'This email was generated automatically. Please do not reply to this email.'
+    159 => 'This email was generated automatically. Please do not reply to this email.',
+    160 => '(max. %d x %d pixels, %d bytes; %s)',
+    161 => 'will be scaled down',
+    162 => 'will not be scaled',
+    163 => 'Re-Authentication Failed',
+    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
+    165 => 'Use Advanced Editor'
 );
 
 ###############################################################################
@@ -400,16 +423,16 @@ $LANG05 = array(
 $LANG08 = array(
     1 => 'There was an error sending your message. Please try again.',
     2 => 'Message sent successfully.',
-    3 => 'Please make sure you use a valid email address in the Reply To field.',
-    4 => 'Please fill in the Your Name, Reply To, Subject and Message fields',
+    3 => 'Please make sure you use a valid email address in the Your Email Address field.',
+    4 => 'Please fill in the Your Name, Your Email Address, Subject and Message fields',
     5 => 'Error: No such user.',
     6 => 'There was an error.',
     7 => 'User Profile for',
-    8 => 'User Name',
+    8 => 'Username',
     9 => 'User URL',
     10 => 'Send mail to',
     11 => 'Your Name:',
-    12 => 'Reply To:',
+    12 => 'Your Email Address',
     13 => 'Subject:',
     14 => 'Message:',
     15 => 'HTML will not be translated.',
@@ -432,7 +455,12 @@ $LANG08 = array(
     32 => 'Date',
     33 => 'Read the full article at',
     34 => 'End of Message',
-    35 => 'Sorry, this user prefers not to receive any emails.'
+    35 => 'Sorry, this user prefers not to receive any emails.',
+    36 => 'Copy:',
+    37 => 'Send me a copy of this email',
+    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:",
+    39 => 'Your last message was ',
+    40 => " seconds ago.  This site requires at least {$_CONF['speedlimit']} seconds between sending messages"    
 );
 
 ###############################################################################
@@ -499,7 +527,18 @@ $LANG09 = array(
     58 => 'More results &gt;&gt;',
     59 => 'Results',
     60 => 'per page',
-    61 => 'Refine search'
+    61 => 'Refine search',
+    62 => '#',
+    63 => 'Description',
+    64 => 'Showing %1$d - %2$d of %3$d results',
+    65 => 'Story',
+    66 => 'Comment',
+    67 => 'Show %d Results',
+    68 => 'Sort By',
+    69 => 'Titles Only',
+    70 => 'Not available ...',
+    71 => 'asc',
+    72 => 'desc'
 );
 
 ###############################################################################
@@ -547,7 +586,8 @@ $LANG11 = array(
     2 => 'Mail Story to a Friend',
     3 => 'Printable Story Format',
     4 => 'Story Options',
-    5 => 'PDF Story Format'
+    5 => '',
+    6 => "Subscribe to '%s'"
 );
 
 ###############################################################################
@@ -681,7 +721,7 @@ $LANG21 = array(
     47 => '',
     48 => 'Block Name',
     49 => ' (no spaces and must be unique)',
-    50 => '',
+    50 => 'The Block Name can not be empty',
     51 => 'include http://',
     52 => 'If you leave this blank the help icon for this block will not be displayed',
     53 => 'Enabled',
@@ -768,7 +808,7 @@ $LANG24 = array(
     60 => '',
     61 => 'Auto Archive',
     62 => 'Auto Delete',
-    63 => '',
+    63 => 'Disable Comments',
     64 => '',
     65 => '',
     66 => '',
@@ -793,7 +833,10 @@ $LANG24 = array(
     85 => 'Show All',
     86 => 'Advanced Editor',
     87 => 'Story Stats',
-    88 => 'Wiki-style format'
+    88 => 'Wiki-style format',
+    89 => 'Meta Description',
+    90 => 'Meta Keywords',
+    91 => 'You can always hit "Preview" to extend the expiry time.'
 );
 
 
@@ -829,7 +872,8 @@ $LANG27 = array(
     26 => 'make this the default topic for archived stories. Only one topic allowed.',
     27 => 'Or Upload Topic Icon',
     28 => 'Maximum',
-    29 => 'File Upload Errors'
+    29 => 'File Upload Errors',
+    30 => 'Stories in Topic'
 );
 
 ###############################################################################
@@ -838,7 +882,7 @@ $LANG27 = array(
 $LANG28 = array(
     1 => 'User Editor',
     2 => 'User ID',
-    3 => 'User Name',
+    3 => 'Username',
     4 => 'Full Name',
     5 => 'Password',
     6 => 'Security Level',
@@ -920,7 +964,12 @@ $LANG28 = array(
     82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the next 30 days.",
     83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will be deleted soon if not accessed.",
     84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
-    85 => 'If you have forgotten the password use the following link: %s'
+    85 => 'If you have forgotten the password use the following link: %s',
+    86 => 'Include',
+    87 => 'Reminders',
+    88 => 'Default Group',
+    89 => 'Check to make this a default group for new users',
+    90 => 'Apply "Default Group" change to existing user accounts'
 );
 
 ###############################################################################
@@ -937,16 +986,19 @@ $LANG29 = array(
     13 => 'Submissions',
     14 => 'Date',
     15 => 'Topic',
-    16 => 'User name',
+    16 => 'Username',
     17 => 'Full name',
     18 => 'Email',
     34 => 'Command and Control',
     35 => 'Story Submissions',
-    36 => '',
+    36 => 'Parent or Comment',
     37 => '',
     38 => 'Submit',
     39 => 'There are no submissions to moderate at this time',
-    40 => 'User Submissions'
+    40 => 'User Submissions',
+    41 => 'Comment Submissions',
+    42 => 'Username',
+    43 => 'Auto-publish Comments?'
 );
 
 ###############################################################################
@@ -954,10 +1006,10 @@ $LANG29 = array(
 
 $LANG31 = array(
     1 => "{$_CONF['site_name']} Mail Utility",
-    2 => 'From',
-    3 => 'Reply-to',
+    2 => 'From Name',
+    3 => 'From Email Address',
     4 => 'Subject',
-    5 => 'Body',
+    5 => 'Message',
     6 => 'Send to:',
     7 => 'All users',
     8 => 'Admin',
@@ -993,7 +1045,7 @@ $LANG32 = array(
     6 => 'Warning: Plugin Already Installed!',
     7 => 'The plugin you are trying to install already exists.  Please delete the plugin before re-installing it',
     8 => 'Plugin Compatibility Check Failed',
-    9 => 'This plugin requires a newer version of Geeklog. Either upgrade your copy of <a href="http://www.geeklog.net">Geeklog</a> or get a newer version of the plugin.',
+    9 => 'This plugin requires a newer version of Geeklog. Please upgrade your copy of <a href="http://www.geeklog.net">Geeklog</a>.',
     10 => '<br' . XHTML . '><b>There are no plugins currently installed.</b><br' . XHTML . '><br' . XHTML . '>',
     11 => 'To modify or delete a plugin, click on that plugin\'s edit icon below. This will show the plugin details including the authors\'s website. Both the installed version and the version returned from the plugin\'s code are shown. This will aid you to know if the plugin needs to be upgraded. To install or upgrade a plugin please consult its documentation.',
     12 => 'no plugin name provided to plugineditor()',
@@ -1022,7 +1074,25 @@ $LANG32 = array(
     35 => 'Edit',
     36 => 'Code',
     37 => 'Data',
-    38 => 'Update!'
+    38 => 'Update!',
+    39 => 'Upload a plugin',
+    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
+    41 => 'Upload',
+    42 => 'Click to update',
+
+    // to match the PHP error constants,
+    // http://www.php.net/manual/en/features.file-upload.errors.php
+    // TBD: move to a separate $LANG array
+     99 => 'An unknown error occured',
+    100 => 'Ok.',
+    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
+    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
+    103 => 'The uploaded file was only partially uploaded.',
+    104 => 'No file was uploaded.',
+    105 => '(undefined error)',
+    106 => 'Missing a temporary folder.',
+    107 => 'Failed to write file to disk.',
+    108 => 'File upload stopped by extension.'
 );
 
 ###############################################################################
@@ -1046,7 +1116,7 @@ $LANG33 = array(
     20 => 'Yes',
     21 => 'No',
     22 => '<i>(no feeds)</i>',
-    23 => 'all Stories',
+    23 => 'All Stories',
     24 => 'Feed Editor',
     25 => 'Feed Title',
     26 => 'Limit',
@@ -1060,7 +1130,7 @@ $LANG33 = array(
     34 => 'Entries',
     35 => 'Hours',
     36 => 'Select type of feed',
-    37 => 'You have at least one plugin installed that supports content syndication. Below you will need to select whether you want to create a Geeklog feed or a feed from one of the plugins.',
+    37 => '',
     38 => 'Error: Missing Fields',
     39 => 'Please fill in the Feed Title, Description, and Filename.',
     40 => 'Please enter a  number of entries or number of hours.',
@@ -1075,7 +1145,10 @@ $LANG33 = array(
     49 => 'Feed Logo',
     50 => "Relative to site url ({$_CONF['site_url']})",
     51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
-    52 => 'Error: existing Filename'
+    52 => 'Error: existing Filename',
+    53 => 'All Frontpage Stories',
+    54 => 'Please select the type of feed to create.',
+    55 => 'Articles'
 );
 
 ###############################################################################
@@ -1096,8 +1169,8 @@ $MESSAGE = array(
     12 => 'The block has been successfully deleted.',
     13 => 'Your topic has been successfully saved.',
     14 => 'The topic and all its stories and blocks have been successfully deleted.',
-    15 => '',
-    16 => '',
+    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
+    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
     17 => '',
     18 => '',
     19 => '',
@@ -1110,25 +1183,25 @@ $MESSAGE = array(
     26 => '',
     27 => 'Message successfully sent.',
     28 => 'The plugin has been successfully saved',
-    29 => '',
+    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
     30 => 'Access Denied',
-    31 => 'Sorry, you do not have access to the story administration page.  Please note that all attempts to access unauthorized features are logged',
-    32 => 'Sorry, you do not have access to the topic administration page.  Please note that all attempts to access unauthorized features are logged',
-    33 => 'Sorry, you do not have access to the block administration page.  Please note that all attempts to access unauthorized features are logged',
+    31 => '',
+    32 => '',
+    33 => '',
     34 => '',
     35 => '',
     36 => '',
-    37 => 'Sorry, you do not have access to the user administration page.  Please note that all attempts to access unauthorized features are logged',
-    38 => 'Sorry, you do not have access to the plugin administration page.  Please note that all attempts to access unauthorized features are logged',
-    39 => 'Sorry, you do not have access to the mail administration page.  Please note that all attempts to access unauthorized features are logged',
+    37 => '',
+    38 => '',
+    39 => '',
     40 => 'System Message',
-    41 => 'Sorry, you do not have access to the word replacement page.  Please note that all attempts to access unauthorized features are logged',
-    42 => 'Your word has been successfully saved.',
-    43 => 'The word has been successfully deleted.',
+    41 => '',
+    42 => '',
+    43 => '',
     44 => 'The plugin was successfully installed!',
     45 => 'The plugin was successfully deleted.',
-    46 => 'Sorry, you do not have access to the database backup utility.  Please note that all attempts to access unauthorized features are logged',
-    47 => 'This functionality only works under *nix.  If you are running *nix as your operating system then your cache has been successfully cleared. If you are on Windows, you will need to search for files name adodb_*.php and remove them manually.',
+    46 => '',
+    47 => '',
     48 => "Thank you for applying for a membership with {$_CONF['site_name']}. Our team will review your application. If approved, your password will be emailed to you at the email address you just entered.",
     49 => 'Your group has been successfully saved.',
     50 => 'The group has been successfully deleted.',
@@ -1177,8 +1250,14 @@ $MESSAGE = array(
     93 => 'Database back up was successful.',
     94 => 'Backup Failed: Filesize less than 1kb',
     95 => 'There was an error.',
-    96 => 'Sorry, you do not have access to the configuration administration page.  Please note that all attempts to access unauthorized features are logged.',
-    97 => 'Not all required fields have been passed validation - default custom membership message'
+    96 => '',
+    97 => '',
+    98 => 'The plugin was successfully uploaded.',
+    99 => 'The plugin already exists.',
+    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
+    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
+    400 => 'Not all required fields have been passed validation', // Error codes in the 400 range reserved for CUSTOM membership
+    401 => 'Please enter Fullname'
 );
 
 ###############################################################################
@@ -1257,7 +1336,10 @@ $LANG_DB_BACKUP = array(
     'do_backup' => 'Do Backup',
     'backup_successful' => 'Database back up was successful.',
     'db_explanation' => 'To create a new backup of your site\'s database, click on "Create New" above. Click on a file name to download that backup.',
-    'not_found' => "Incorrect path or mysqldump utility not executable.<br' . XHTML . '> Check <strong>mysqldump_path</strong> definition in the Configuration.<br' . XHTML . '> Path currently defined as: <var>{$_DB_mysqldump_path}</var>",
+    'not_found' => 'Incorrect path, security restriction in effect or mysqldump utility not executable.<br'
+                    . XHTML . '> Check <strong>mysqldump_path</strong> definition in the Configuration.<br'
+                    . XHTML . '> Check <a href="http://www.php.net/manual/en/features.safe-mode.php#ini.open-basedir">open_basedir</a> settings in PHP.<br'
+                    . XHTML . "> Path currently defined as: <var>{$_DB_mysqldump_path}</var>",
     'zero_size' => 'Backup Failed: Filesize was 0 bytes',
     'path_not_found' => "{$_CONF['backup_path']} does not exist or is not a directory",
     'no_access' => "ERROR: Directory {$_CONF['backup_path']} is not accessible.",
@@ -1265,7 +1347,27 @@ $LANG_DB_BACKUP = array(
     'size' => 'Size',
     'bytes' => 'Bytes',
     'total_number' => 'Total number of backups: %d',
-    'download' => 'Click to download this file'
+    'download' => 'Click to download this file',
+    'new_backup' => 'New Backup',
+    'delete_failure' => 'One or more backup files could not be deleted.',
+    'delete_success' => 'Backup file(s) successfully deleted.',
+    'convert_menu' => 'Convert to InnoDB',
+    'convert_title' => 'Convert to InnoDB tables',
+    'convert_button' => 'Convert',
+    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
+    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
+    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
+    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
+    'innodb_success' => 'Successfully converted tables to InnoDB.',
+    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
+
+    'optimize_menu' => 'Optimize Tables',
+    'optimize_title' => 'Optimize Tables',
+    'optimize_button' => 'Optimize',
+    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
+    'last_optimization' => 'Last optimization',
+    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
+    'optimize_success' => 'Successfully optimized database tables.'
 );
 
 ###############################################################################
@@ -1302,23 +1404,6 @@ $LANG_LOGIN = array(
     4 => 'New User'
 );
 
-$LANG_PDF = array(
-    1 => 'The PDF feature has been disabled',
-    2 => 'The document provided was not rendered. The document was received but could not be processed.  Please make sure to submit only html formatted documents that have been written to the xHTML standard. Please note that overly complex html documents may not render correctly or at all. The document resulting from your attempt was 0 bytes in length, and has been deleted. If you\'re sure that your document should render fine, please re-submit it.',
-    3 => 'Unknown error during PDF generation',
-    4 => 'No page data was given or you want to use the ad-hoc PDF generation tool below.  If you think you are getting this page in error then please contact the system administrator.  Otherwise, you may use the form below to generate PDF\'s in an ad-hoc fashion.',
-    5 => 'Loading your document.',
-    6 => 'Please wait while your document is loaded.',
-    7 => 'You may right click the button below and choose \'save target...\' or \'save link location...\' to save a copy of your document.',
-    8 => 'The path given in the configuration file to the HTMLDoc binary is invalid or this system cannot execute it.  Please contact the site administrator if this problem persists.',
-    9 => 'PDF Generator',
-    10 => 'This is the Ad-hoc PDF Generation tool. It will attempt to convert any URL you give into a PDF.  Please note that some web pages will not render properly with this feature.  This is a limitation of the HTMLDoc PDF generation tool and such errors should not be reported to the administrators of this site',
-    11 => 'URL',
-    12 => 'Generate PDF!',
-    13 => 'The PHP configuration on this server does not allow URLs to be used with the fopen() command.  The system administrator must edit the php.ini file and set allow_url_fopen to On',
-    14 => 'The PDF you requested either does not exist or you tried to illegally access a file.'
-);
-
 ###############################################################################
 # trackback
 
@@ -1417,6 +1502,31 @@ $LANG_DIR = array (
     'no_articles'      => 'No articles.'
 );
 
+###############################################################################
+# admin/sectest.php
+
+$LANG_SECTEST = array(
+    'sectest'       => 'Geeklog Security Check',
+    'results'       => 'Results of the Security Check',
+    'okay'          => 'Everything seems to be in order.',
+    'please_fix'    => 'Please fix the above issues before using your site!',
+    'please_note'   => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
+    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
+    'public_html'   => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
+    'installation'  => 'installation instructions',
+    'directory'     => 'directory',
+    'failed_tmp'    => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
+    'fix_it'        => 'This is a security risk and should be fixed!',
+    'reachable'     => 'Your %s is reachable from the web.',
+    'not_reachable' => 'Good! Your %s is not reachable from the web.',
+    'not_sure'      => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
+    'remove_inst'   => 'You should really remove the install directory %s once you have your site up and running without any errors.', 
+    'remove_inst2'  => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
+    'inst_removed'  => 'Good! You seem to have removed the install directory already.',
+    'fix_password'  => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
+    'password_okay' => 'Good! You seem to have changed the default account password already.'
+);
+
 ################################################################################
 # "What's New" Time Strings
 
@@ -1435,11 +1545,13 @@ $LANG_WHATSNEW = array (
     'days'        => 'days',
     'weeks'       => 'weeks',
     'months'      => 'months',
+    'years'       => 'years',
     'minute'      => 'minute',
     'hour'        => 'hour',
     'day'         => 'day',
     'week'        => 'week',
-    'month'       => 'month'
+    'month'       => 'month',
+    'year'        => 'year'
 );
 
 $LANG_MONTH = array(
@@ -1484,6 +1596,7 @@ $LANG_ADMIN = array (
     'create_new_adv'=> 'Create New (Adv.)',
     'enabled'       => 'Enabled',
     'title'         => 'Title',
+    'page_title'    => 'Page Title',
     'type'          => 'Type',
     'topic'         => 'Topic',
     'help_url'      => 'Help File URL',
@@ -1498,7 +1611,14 @@ $LANG_ADMIN = array (
     'records_found' => 'Records found',
     'addchild'      => 'Add child',
     'list'          => 'list',
-    'list_all'      => 'List all'
+    'list_all'      => 'List all',
+    'meta_description' => 'Meta Description',
+    'meta_keywords' => 'Meta Keywords',        
+    'na'            => 'N/A',
+    'token_expiry'  => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
+    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
+    'reauth_msg'    => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
+    'authenticate'  => 'Authenticate'
 );
 
 # Localisation of the texts for the various drop-down menus that are actually
@@ -1570,7 +1690,9 @@ $LANG_CONFIG = array(
     'save_changes'  => 'Save Changes',
     'reset_form'    => 'Reset Form',
     'changes_made'  => 'Changes were successfully made to',
-    'title'         => 'Configuration Manager'
+    'title'         => 'Configuration Manager',
+    'disable'       => 'Click to disable this option',
+    'enable'        => 'Enable'
 );
 
 $LANG_configsections['Core'] = array(
@@ -1598,7 +1720,9 @@ $LANG_confignames['Core'] = array(
     'allow_mysqldump' => "Allow MySQL Dump",
     'mysqldump_path' => 'Path of Executable',
     'mysqldump_options' => "MySQL Dump Options",
+    'mysqldump_filename_mask' => 'Backup File Name Mask',
     'theme' => "Theme",
+    'doctype' => 'DOCTYPE Declaration',
     'menu_elements' => "Menu Elements",
     'path_themes' => "Themes Path",
     'disable_new_user_registration' => "Disable New Registrations",
@@ -1619,7 +1743,7 @@ $LANG_confignames['Core'] = array(
     'date' => "Date Format",
     'daytime' => "Daytime Format",
     'shortdate' => "Short Date Format",
-    'dateonly' => "Date Only Format", 
+    'dateonly' => "Date Only Format",
     'timeonly' => "Time Only Format",
     'week_start' => "Week Start",
     'hour_mode' => "Hour Mode",
@@ -1637,6 +1761,7 @@ $LANG_confignames['Core'] = array(
     'cookie_theme' => "Theme Cookie Name",
     'cookie_language' => "Language Cookie Name",
     'cookie_tzid' => "Timezone Cookie Name",
+    'cookie_anon_name' => 'Anon. Username Cookie Name',
     'cookie_ip' => "Cookies embed IP?",
     'default_perm_cookie_timeout' => "Permanent Timeout",
     'session_cookie_timeout' => "Session Timeout",
@@ -1644,7 +1769,6 @@ $LANG_confignames['Core'] = array(
     'cookiedomain' => "Cookie Domain",
     'cookiesecure' => "Cookie Secure",
     'lastlogin' => "Record Last Login?",
-    'pdf_enabled' => "PDF Enabled?",
     'num_search_results' => "Number of Search Results",
     'loginrequired' => "Login Required?",
     'submitloginrequired' => "Submit Login Required?",
@@ -1728,6 +1852,7 @@ $LANG_confignames['Core'] = array(
     'debug_image_upload' => "Debug Image Uploading?",
     'keep_unscaled_image' => "Keep Unscaled Image?",
     'allow_user_scaling' => "Allow User Scaling?",
+    'jpeg_quality' => 'JPEG Quality?',
     'max_image_width' => "Max Image Width?",
     'max_image_height' => "Max Image Height?",
     'max_image_size' => "Max Image Size?",
@@ -1738,32 +1863,55 @@ $LANG_confignames['Core'] = array(
     'max_photo_height' => "Max Photo Height?",
     'max_photo_size' => "Max Photo Size?",
     'use_gravatar' => "Use Gravatar?",
-    'gravatar_rating' => "Gravatar Rating Allowed",
+    'gravatar_rating' => "Gravatar Rating",
     'force_photo_width' => "Force Photo Width",
     'default_photo' => "Default Photo",
     'commentspeedlimit' => "Comment Speed Limit",
     'comment_limit' => "Comment Limit",
     'comment_mode' => "Comment Mode",
     'comment_code' => "Comment Default",
+    'comment_edit' => "Allow Comment Edit?",
+    'comment_edittime' => "Comment Edit Time (seconds)",
+    'commentsubmission' => "Queue Comment Submissions",
     'passwordspeedlimit' => "Password Speed Limit",
     'login_attempts' => "Max. Login Attempts",
     'login_speedlimit' => "Login Speed Limit",
     'user_html' => "User HTML",
     'admin_html' => "Admin HTML",
+    'advanced_html' => 'Additional HTML for Adv. Editor',
     'skip_html_filter_for_root' => "Skip HTML Filter for Root?",
     'allowed_protocols' => "Allowed Protocols",
-    'disable_autolinks' => "Disable Autolinks?",
+    'disable_autolinks' => "Disable Autotags?",
+    'clickable_links' => 'Make URLs clickable?',
+    'compressed_output' => 'Send compressed output?',
+    'frame_options' => 'Protection against "clickjacking"',
     'censormode' => "Censor Mode?",
     'censorreplace' => "Censor Replace Text",
     'censorlist' => "Censor List",
     'ip_lookup' => "IP Lookup",
     'url_rewrite' => "Enable URL Rewrite",
+    'meta_tags' => "Meta Tags",
+    'meta_description' => "Default Meta Description",
+    'meta_keywords' => "Default Meta Keywords",    
     'default_permissions_block' => "Block Default Permissions",
     'default_permissions_story' => "Story Default Permissions",
     'default_permissions_topic' => "Topic Default Permissions",
     'atom_max_stories' => "Max. Stories in Webservices Feed",
     'disable_webservices' => 'Disable Webservices?',
-    'restrict_webservices' => 'Restrict Webservices?'
+    'restrict_webservices' => 'Restrict Webservices?',
+    'article_comment_close_enabled' => 'Automatically close comments (default)',
+    'article_comment_close_days' => 'Days to close comments (default)',
+    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
+    'allow_reply_notifications' => 'Allow comment reply notifications?',
+    'search_style' => "Results List Style",
+    'search_limits' => "Page Limits",
+    'search_show_num' => "Show Result Number?",
+    'search_show_type' => "Show Result Type?",
+    'search_show_sort' => "Allow User to Sort Results?",
+    'search_show_limit' => "Show Page Limits?",
+    'search_separator' => "Group Separator",
+    'search_def_keytype' => "Default Search Method",
+    'search_def_sort' => "Default Sort Order"
 );
 
 $LANG_configsubgroups['Core'] = array(
@@ -1846,7 +1994,17 @@ $LANG_configselects['Core'] = array(
     14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
     15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
     16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
-    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1)
+    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
+    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
+    19 => array('Google' => 'google', 'Table' => 'table'),
+    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
+    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
+    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
+    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
+    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
+    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
+    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
+    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
 );
 
 ?>
