@@ -462,7 +462,9 @@ $LANG08 = array(
     35 => 'Sorry, dieser User möchte keine E-Mails bekommen.',
     36 => 'Kopie:',
     37 => 'Ich möchte eine Kopie der E-Mail bekommen',
-    38 => "Dies ist eine Kopie der E-Mail, die Sie von <{$_CONF['site_url']}> an %s gesendet haben:"
+    38 => "Dies ist eine Kopie der E-Mail, die Sie von <{$_CONF['site_url']}> an %s gesendet haben:",
+    39 => 'Your last message was ',
+    40 => " seconds ago.  This site requires at least {$_CONF['speedlimit']} seconds between sending messages"
 );
 
 ###############################################################################
@@ -1539,11 +1541,13 @@ $LANG_WHATSNEW = array(
     'days' => 'Tage',
     'weeks' => 'Wochen',
     'months' => 'Monate',
+    'years' => 'Jahre',
     'minute' => 'Minute',
     'hour' => 'Stunde',
     'day' => 'Tag',
     'week' => 'Woche',
-    'month' => 'Monat'
+    'month' => 'Monat',
+    'year' => 'Jahr'
 );
 
 ###############################################################################
